==> kubernetes-client-4.13.3-sources.jar: io/fabric8/kubernetes/client/handlers/core/v1/PodTemplateHandler.java <==

                                          

package io.fabric8.kubernetes.client.handlers.core.v1;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.core.v1.PodTemplateOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.kubernetes.api.model.PodTemplate;
import io.fabric8.kubernetes.api.model.PodTemplateBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class PodTemplateHandler implements ResourceHandler<PodTemplate, PodTemplateBuilder> {

  @Override
  public String getKind() {
    return PodTemplate.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "v1";
      }

  @Override
  public PodTemplate create(OkHttpClient client, Config config, String namespace, PodTemplate item) {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public PodTemplate replace(OkHttpClient client, Config config, String namespace, PodTemplate item) {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public PodTemplate reload(OkHttpClient client, Config config, String namespace, PodTemplate item) {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public PodTemplateBuilder edit(PodTemplate item) {
    return new PodTemplateBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, PodTemplate item) {
    return new PodTemplateOperationsImpl(client, config, namespace).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, PodTemplate item, Watcher<PodTemplate> watcher) {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, PodTemplate item, String resourceVersion, Watcher<PodTemplate> watcher) {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, PodTemplate item, ListOptions options, Watcher<PodTemplate> watcher) {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }

  @Override
  public PodTemplate waitUntilReady(OkHttpClient client, Config config, String namespace, PodTemplate item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public PodTemplate waitUntilCondition(OkHttpClient client, Config config, String namespace, PodTemplate item, Predicate<PodTemplate> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> kubernetes-client-5.3.0-sources.jar: io/fabric8/kubernetes/client/handlers/core/v1/PodTemplateHandler.java <==

                                          

package io.fabric8.kubernetes.client.handlers.core.v1;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.core.v1.PodTemplateOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.kubernetes.api.model.PodTemplate;
import io.fabric8.kubernetes.api.model.PodTemplateBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class PodTemplateHandler implements ResourceHandler<PodTemplate, PodTemplateBuilder> {

  @Override
  public String getKind() {
    return PodTemplate.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "v1";
      }

  @Override
  public PodTemplate create(OkHttpClient client, Config config, String namespace, PodTemplate item, boolean dryRun) {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public PodTemplate replace(OkHttpClient client, Config config, String namespace, PodTemplate item, boolean dryRun) {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public PodTemplate reload(OkHttpClient client, Config config, String namespace, PodTemplate item) {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public PodTemplateBuilder edit(PodTemplate item) {
    return new PodTemplateBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, PodTemplate item, boolean dryRun) {
    return new PodTemplateOperationsImpl(client, config, namespace).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

@Override
  public Watch watch(OkHttpClient client, Config config, String namespace, PodTemplate item, Watcher<PodTemplate> watcher) {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, PodTemplate item, String resourceVersion, Watcher<PodTemplate> watcher) {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, PodTemplate item, ListOptions options, Watcher<PodTemplate> watcher) {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }

  @Override
  public PodTemplate waitUntilReady(OkHttpClient client, Config config, String namespace, PodTemplate item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public PodTemplate waitUntilCondition(OkHttpClient client, Config config, String namespace, PodTemplate item, Predicate<PodTemplate> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new PodTemplateOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
